@@ -1,13 +1,13 @@
-############################################################################### 
-## abn-toolbox.R --- 
-## Author : Gilles Kratzer 
-## Document created : 01/02/2017 
-## Last modification : 01/02/2017 
-## Last modification : 11/04/2017 (compareDag, infoDag) 
-## Last modification : 21/04/2017 (simulateDag) 
-## Last modification : 29/08/2017 (compareDag (G and F1 score), essential.graph (minimal vs completed)) 
+###############################################################################
+## abn-toolbox.R ---
+## Author : Gilles Kratzer
+## Document created : 01/02/2017
+## Last modification : 01/02/2017
+## Last modification : 11/04/2017 (compareDag, infoDag)
+## Last modification : 21/04/2017 (simulateDag)
+## Last modification : 29/08/2017 (compareDag (G and F1 score), essential.graph (minimal vs completed))
 ## Last modification : 16/07/2018 error in Hamming distance corrected
-############################################################################### 
+###############################################################################
 
 ##-------------------------------------------------------------------------
 ## External usefull functions to analayse ABN and BN
@@ -25,22 +25,22 @@ expit <- function(x) {
 
 # function that compute an odds ratio from a table/matrix
 or <- function(x) {
-    
+
     x <- as.matrix(x)
-    
+
     if (dim(x)[1] != 2 || dim(x)[2] != 2) {
         stop("The contengency table should be of 2-dimensionnal with a 2x2 formulation.")
     }
-    
+
     if (x[1, 2] == 0) {
         x[1, 2] <- 0.5
     }
     if (x[2, 1] == 0) {
         x[2, 1] <- 0.5
     }
-    
+
     out <- (x[1, 1] * x[2, 2])/(x[1, 2] * x[2, 1])
-    
+
     return(out)
 }
 
@@ -55,7 +55,7 @@ odds <- function(x) {
 
 
 compareDag <- function(ref, test, node.names = NULL) {
-    
+
     ## check ref dag
     ref <- validate_abnDag(  ref, data.df=node.names, returnDAG=TRUE)
     test <- validate_abnDag( test, data.df=node.names, returnDAG=TRUE)
@@ -63,24 +63,24 @@ compareDag <- function(ref, test, node.names = NULL) {
     if (any(dim(ref) != dim(test))) {
         stop("The reference or test DAG has not the same size")
     }
-    
+
     n <- dim(ref)[1]
-    
+
     ## unit matrix
     ref[ref != 0] <- 1
     test[test != 0] <- 1
-    
+
     diff.matrix <- ref - (0.5 * test)
-    
+
     diff.matrix.tab <- table(factor(diff.matrix, levels = c(-0.5, 0, 0.5, 1)))
-    
+
     if(sum(ref == 1)==0 | sum(test == 1)==0){
         warning("If the test or reference matrix is an empty matrix some of the estimates are not defined.")
     }
-    
+
     ## output
     out <- list()
-    
+
     out[["TPR"]] <- (as.numeric(diff.matrix.tab[names(diff.matrix.tab) == 0.5]))/(sum(ref == 1))
     out[["FPR"]] <- (as.numeric(diff.matrix.tab[names(diff.matrix.tab) == -0.5]))/(sum(ref == 0))
     out[["Accuracy"]] <- (as.numeric(diff.matrix.tab[names(diff.matrix.tab) == 0.5]) + as.numeric(diff.matrix.tab[names(diff.matrix.tab) == 0]))/(dim(ref)[1]^2)
@@ -89,7 +89,7 @@ compareDag <- function(ref, test, node.names = NULL) {
     out[["F1-score"]] <- (2/((1/as.numeric(diff.matrix.tab[names(diff.matrix.tab) == 0.5])/(sum(test == 1))) + (1/(as.numeric(diff.matrix.tab[names(diff.matrix.tab) == 0.5]))/(sum(ref == 1)))))
     out[["PPV"]] <- as.numeric(diff.matrix.tab[names(diff.matrix.tab) == 0.5])/(sum(test == 1))
     out[["FOR"]] <- as.numeric(diff.matrix.tab[names(diff.matrix.tab) == 1])/(sum(test == 1))
-    
+
     # transforming "reverse arc" into -0.5
     for( i in 1:n){
         for( j in i:n){
@@ -99,11 +99,11 @@ compareDag <- function(ref, test, node.names = NULL) {
             }
         }
     }
-    
+
     diff.matrix.tab <- table(factor(diff.matrix, levels = c(-0.5, 0, 0.5, 1)))
-    
+
     out[["Hamming-distance"]] <- sum(as.numeric(diff.matrix.tab[names(diff.matrix.tab) %in% c(-0.5, 1)]))
-    
+
     return(out)
 }
 
@@ -113,7 +113,7 @@ compareDag <- function(ref, test, node.names = NULL) {
 ##-------------------------------------------------------------------------
 
 infoDag <- function(dag, node.names = NULL) {
-    
+
     ## dag transformation
     if (!is.null(dag)) {
         if (is.matrix(dag)) {
@@ -135,35 +135,35 @@ infoDag <- function(dag, node.names = NULL) {
     } else {
         stop("Dag specification must either be a matrix or a formula expression")
     }
-    
+
     dag[dag != 0] <- 1
     diag(dag) <- 0
-    
+
     if (is.null(node.names) & is.null(colnames(dag))) {
         stop("Either name have to be provided with a formula statement either a named matrix to define a DAG")
     }
     if (is.null(node.names)) {
         node.names <- colnames(dag)
     }
-    
+
     ## ======================== test for conformity over! ========================
-    
+
     out <- list()
     ## number of nodes
     n.nodes <- dim(dag)[1]
-    
+
     ## number of arcs
     n.arcs <- sum(dag)
-    
+
     ## =========================== average markov blanket size ===========================
-    
+
     mb.size <- vector(mode = "numeric", length = length(node.names))
-    
+
     for (i in 1:length(node.names)) {
-        
+
         node <- node.names[i]
         # row children column parent
-        
+
         ## Parent + Children
         mb.children <- list()
         mb.parent <- list()
@@ -178,7 +178,7 @@ infoDag <- function(dag, node.names = NULL) {
         # delete NULL element
         mb.children <- unlist(mb.children[!sapply(mb.children, is.null)])
         mb.parent <- unlist(mb.parent[!sapply(mb.parent, is.null)])
-        
+
         ## Parent of children
         mb.parent.children <- list()
         for (node.children in mb.children) {
@@ -190,13 +190,13 @@ infoDag <- function(dag, node.names = NULL) {
         }
         # delete NULL element
         mb.parent.children <- unlist(mb.parent.children[!sapply(mb.parent.children, is.null)])
-        
+
         # add all list
         mb.node <- unlist(list(mb.children, mb.parent, mb.parent.children))
-        
+
         # unique element
         mb.node <- unique(mb.node)
-        
+
         # delete index node
         mb.node.wo <- NULL
         if (length(mb.node) != 0) {
@@ -209,18 +209,18 @@ infoDag <- function(dag, node.names = NULL) {
         if (is.null(mb.node.wo)) {
             mb.node.wo <- mb.node
         }
-        
+
         mb.size[i] <- length(mb.node.wo)
     }
-    
+
     mb.average <- mean(mb.size)
-    
+
     ## average Neighborhood
-    
+
     nh.size <- vector(mode = "numeric", length = length(node.names))
     parent.size <- vector(mode = "numeric", length = length(node.names))
     children.size <- vector(mode = "numeric", length = length(node.names))
-    
+
     for (i in 1:length(node.names)) {
         nh.size[i] <- sum(dag[i, ]) + sum(dag[, i])
         parent.size[i] <- sum(dag[i, ])
@@ -229,7 +229,7 @@ infoDag <- function(dag, node.names = NULL) {
     nh.average <- mean(nh.size)
     parent.average <- mean(parent.size)
     children.average <- mean(children.size)
-    
+
     ## output
     out[["n.nodes"]] <- n.nodes
     out[["n.arcs"]] <- n.arcs
@@ -237,7 +237,7 @@ infoDag <- function(dag, node.names = NULL) {
     out[["nh.average"]] <- nh.average
     out[["parent.average"]] <- parent.average
     out[["children.average"]] <- children.average
-    
+
     return(out)
 }
 
@@ -245,36 +245,36 @@ infoDag <- function(dag, node.names = NULL) {
 ## External function that simulate a dag with arbitrary arcs density
 ##-------------------------------------------------------------------------
 
-simulateDag <- function(node.name = NULL, data.dists = NULL, nn = 0.5) {
-    
+simulateDag <- function(node.name = NULL, data.dists = NULL, edge.density = 0.5) {
+
     ## test
     if (length(node.name) <= 2) {
         stop("No need for help to simulate a DAG of size 2")
     }
-    if (nn > 1 | nn < 0) {
-        stop("The network density should be a real number in [0,1]")
+    if (edge.density > 1 | edge.density < 0) {
+        stop("'edge.density' should be a real number in [0,1]")
     }
-    
+
     if (is.null(data.dists)) {
         data.dists <- sample(x = c("gaussian", "binomial", "poisson"), size = length(node.name), replace = TRUE)
         names(data.dists) <- node.name
     }
-    
+
     dag <- matrix(data = 0, nrow = length(node.name), ncol = length(node.name))
-    
-    
+
+
     for (j in 2:(length(node.name))) {
-        dag[c(j:length(node.name)), (j - 1)] <- rbinom(n = (length(node.name) - j + 1), size = 1, prob = nn)
+        dag[c(j:length(node.name)), (j - 1)] <- rbinom(n = (length(node.name) - j + 1), size = 1, prob = edge.density)
     }
     order.m <- sample(x = length(node.name), size = length(node.name), replace = FALSE)
-    
+
     ## changing order
     dag <- dag[order.m, order.m]  #order.m
-    
+
     ## naming
     colnames(dag) <- rownames(dag) <- node.name
-    
-    out <- create_abnDag(dag, data.dists=data.dists)
+
+    out <- createAbnDag(dag, data.dists=data.dists)
     ## structure
     return(out)
 }
@@ -300,7 +300,7 @@ essentialGraph <- function(dag, node.names = NULL, PDAG = "minimal") {
         # check.valid.dag(dag.m=dag.m,data.df=data.df,is.ban.matrix=FALSE,group.var=group.var) unit matrix
         dag[dag != 0] <- 1
         node.names <- colnames(dag)
-        
+
     } else {
         if (grepl("~", as.character(dag)[1], fixed = TRUE)) {
             dag <- formula.abn(f = dag, name = node.names)
@@ -308,12 +308,12 @@ essentialGraph <- function(dag, node.names = NULL, PDAG = "minimal") {
             stop("Dag specification must either be a matrix or a formula expression")
         }
     }
-    
+
     ## compute essential graph moral graph
-    
+
     dim.dag <- dim(dag)[1]
     moral <- matrix(data = 0, nrow = dim.dag, ncol = dim.dag)
-    
+
     for (i in 1:dim.dag) {
         for (j in 1:dim.dag) {
             if (dag[i, j] == 1) {
@@ -322,9 +322,9 @@ essentialGraph <- function(dag, node.names = NULL, PDAG = "minimal") {
             }
         }
     }
-    
+
     colnames(moral) <- rownames(moral) <- node.names
-    
+
     ## essential arcs
     if (PDAG == "minimal") {
         for (i in 1:dim.dag) {
@@ -336,12 +336,12 @@ essentialGraph <- function(dag, node.names = NULL, PDAG = "minimal") {
                 }
             }
         }
-        
-        
+
+
         colnames(moral) <- rownames(moral) <- node.names
         return(moral)
     }
-    
+
     if (PDAG == "completed") {
         for (i in 1:dim.dag) {
             if (sum(dag[i, ]) >= 2) {
@@ -355,7 +355,7 @@ essentialGraph <- function(dag, node.names = NULL, PDAG = "minimal") {
                 }
             }
         }
-        
+
         colnames(moral) <- rownames(moral) <- node.names
         return(moral)
     }
@@ -365,70 +365,70 @@ essentialGraph <- function(dag, node.names = NULL, PDAG = "minimal") {
 ##Function that compute likelihood contribution of observation
 ##-------------------------------------------------------------------------
 
-scoreContribution <- function(object = NULL, 
-                              dag.m = NULL, 
+scoreContribution <- function(object = NULL,
+                              dag = NULL,
                               data.df = NULL,
                               data.dists = NULL,
                               verbose = FALSE){
-    
+
     ## method abnCache
     if (!is.null(object)){
         if (inherits(object, "abnLearned")) {
-            dag.m <- object$dag
+            dag <- object$dag
             data.df <- object$score.cache$data.df
             data.dists <- object$score.cache$data.dists
         }}
-    
+
     ## transform factor into 0/1
-    
+
     node.ordering <- names(data.dists)
     nobs <- dim(data.df)[1]
-    
+
     ll <- matrix(data = 0,nrow = dim(data.df)[1],ncol = dim(data.df)[2])
     nb.param <- matrix(data = 0,nrow = dim(data.df)[1],ncol = dim(data.df)[2])
     nb.parents <- matrix(data = 0,nrow = dim(data.df)[1],ncol = dim(data.df)[2])
     colnames(ll) <- colnames(nb.param) <- colnames(nb.parents) <- node.ordering
-    nb.parents <- rowSums(dag.m)/nobs
+    nb.parents <- rowSums(dag)/nobs
     for (node in node.ordering) {
-        
+
         if(as.character(data.dists[node])=="binomial"){
             Y <- as.factor(data.matrix(data.df[, node]))
         } else {
             Y <- data.matrix(data.df[, node])
         }
-        X <- data.matrix(cbind(rep(1,nobs),data.df[, as.logical(dag.m[node,])]))
+        X <- data.matrix(cbind(rep(1,nobs),data.df[, as.logical(dag[node,])]))
         if(as.character(data.dists[node])=="gaussian"){
             nb.param[,node] <- (dim(X)[2] + 1)/nobs
         }else{
             nb.param[,node] <- dim(X)[2]/nobs
         }
-        
+
         x <- glm(formula = Y ~ -1 + X,family = as.character(data.dists[node]))
         yhat <- predict.glm(x,newdata = x$data, type = "response")
-        
+
         switch (as.character(data.dists[node]),
                 "binomial" = {
                     ll[,node] <- dbinom(as.numeric(Y)-1, size = 1L, prob = yhat, log = TRUE)
                 },
                 "gaussian" = {
-                    ll[,node] <- dnorm(Y, mean = yhat, sd = sigma(x),log = TRUE)              
+                    ll[,node] <- dnorm(Y, mean = yhat, sd = sigma(x),log = TRUE)
                 },
                 "poisson" = {
                     ll[,node] <- dpois(Y, lambda = yhat, log = TRUE)
                 }
         )
         hv <- hatvalues(x)
-        
+
     }
-    
+
     aic <- - 2*ll + 2*nb.param
     bic <- - 2*ll + nb.param*(log(nobs))
     mdl <- bic + (1/nobs + nb.parents) * log(nobs)
-    
+
     out <- list("mlik" = ll, "aic" = aic, "bic" = bic, "mdl" = mdl, "hatvalues" = hv)
-    
+
     return(out)
-    
+
 }
 
 
